/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.fritzmeijer;

import java.awt.Component;
import java.awt.Graphics;
import java.awt.Rectangle;
import java.beans.PropertyChangeListener;
import java.beans.PropertyEditor;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import org.openide.util.NbBundle;

/**
 * Custom property editor for time values notated as HHmmss.SS or HHmmss
 * Will return a date of first of January 1970 with a time set to the parsed value.  
 * @author Merijn Zengers
 */
public class UtcTimePropertyEditor implements PropertyEditor {

    private static final SimpleDateFormat TIME_FORMAT_MILIS = new SimpleDateFormat("HHmmss.SS");
    private static final SimpleDateFormat TIME_FORMAT = new SimpleDateFormat("HH.mm.ss");
    private Date utcTime;
    private static final AppLogger LOG = AppLogFactory.getLogger(UtcTimePropertyEditor.class);

    @Override
    public void setValue(Object value) {
        setAsText(value.toString());
    }

    @Override
    public Object getValue() {
        return utcTime;
    }

    @Override
    public boolean isPaintable() {
        return false;
    }

    @Override
    public void paintValue(Graphics gfx, Rectangle box) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public String getJavaInitializationString() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public String getAsText() {
        return utcTime.toString();
    }

    @Override
    public void setAsText(String text) throws IllegalArgumentException {
        try {
            if (text.contains(".") && text.length() == 9) {
                this.utcTime = TIME_FORMAT_MILIS.parse(text);
            } else {
                this.utcTime = TIME_FORMAT.parse(text);
            }
        } catch (ParseException ex) {
            LOG.error(NbBundle.getMessage(UtcTimePropertyEditor.class, "sensor.cropcircle.fileprocessor.logerror.failed_to_create_time", text), ex);
            throw (new RuntimeException(ex));
        }
    }

    @Override
    public String[] getTags() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public Component getCustomEditor() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public boolean supportsCustomEditor() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void addPropertyChangeListener(PropertyChangeListener listener) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void removePropertyChangeListener(PropertyChangeListener listener) {
        throw new UnsupportedOperationException("Not supported yet.");
    }
}
